@@ -8,7 +8,20 @@ use JSON;
 use CGI::Lazy::Globals;
 use base qw(CGI::Lazy::Ajax);
 
-our $widgetprefix = 'CMP';
+#----------------------------------------------------------------------------------------
+sub ajaxBlank {
+	my $self = shift;
+
+	my $widgets 	= [];
+	my $output 	= [];
+
+	foreach (@{$self->memberarray}) {
+		push @$widgets, $_;
+		push @$widgets, $_->ajaxBlank;
+	}
+
+	return $self->ajaxReturn($widgets, $output);
+}
 
 #----------------------------------------------------------------------------------------
 sub ajaxSelect {
@@ -22,6 +35,15 @@ sub ajaxSelect {
 	return $self->$method;
 }
 
+#----------------------------------------------------------------------------------------
+sub ajaxSelectManual {
+	my $self = shift;
+	my %args = shift;
+
+
+	return;
+}
+
 #----------------------------------------------------------------------------------------
 sub ajaxSelectParentChild {
 	my $self = shift;
@@ -119,6 +141,14 @@ sub dbwrite {
 
 }
 
+#----------------------------------------------------------------------------------------
+sub dbwriteManual {
+	my $self = shift;
+	my %args = @_;
+	
+	return;
+}
+
 #----------------------------------------------------------------------------------------
 sub dbwriteParentChild {
        	my $self = shift;
@@ -190,10 +220,9 @@ sub new {
 	return bless {
 		_q 		=> $q, 
 		_vars 		=> $vars, 
-		_widgetprefix 	=> $widgetprefix, 
 		_members 	=> $members, 
 		_widgetID 	=> $widgetID,
-		_type		=> $vars->{type},
+		_type		=> $vars->{type} || 'manual',
 		_relationship	=> $vars->{relationship},
 	}, $class;
 }
@@ -284,6 +313,10 @@ parentChild is pretty experimental.  The configuration given in the example work
 
 =head1 METHODS
 
+=head2 ajaxBlank ()
+
+returns blank versions of all member widgets.
+
 =head2 ajaxSelect ()
 
 Runs select query on parameters incoming via ajax call for all member widgets based on widget type.  Returns results formatted for return to browser via ajax handler.
